@@ -355,12 +355,10 @@ class ORM(object):
         rev = self.rev
         yield (branch, rev)
         while branch != 'master':
-            self.cursor.execute(
+            yield self.cursor.execute(
                 "SELECT parent, parent_rev FROM branches WHERE branch=?;",
                 (branch,)
-            )
-            (branch, rev) = self.cursor.fetchone()
-            yield (branch, rev)
+            ).fetchone()
 
     def _iternodes(self, graphn):
         """Iterate over all nodes that presently exist in the graph"""
